A feed-forward neural network (FFNN) model to predict the HKL in single/multi-grain/multi-phase Laue patterns with high efficiency and accuracy is introduced. Laue micro-diffraction is a X-ray scattering technique for the determination of local structural parameters (strain, stress and orientation) in materials from microstructure mapping (2D and 3D). The use of a polychromatic beam offers many experimental advantages (no rotation of the sample, many diffraction spots, signal that can be used even in the presence of strong orientation disorder). However, in the case of polycrystalline microstructures, the determination of the structural parameters (lattice parameters) from the fine analysis of the relative position of the spots requires identifying unambiguously all the spots forming the Laue pattern corresponding to an individual crystal among all other spots. The indexation step of the data analysis must be reliable to input unambiguous experimental dataset to the structural model refinement (final step in analysis) and rapid since production rate of data on the synchrotron line can amount to several 10000s diffraction images per hour, each image (Laue patterns) being able to contain contribution from multi-grain/ multi-phase present in the probed volume of the material.